/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 *
 * This file is part of Jalview.
 *
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *
 * Jalview is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.util.dialogrunner;

/**
 * A Runnable that is kind of like a future, that allows a sequence of Runabbles
 * to be conditionally executed by DialogRunner
 * 
 * @author jprocter
 *
 */
public abstract class RunResponse implements Runnable
{
  /**
   * Response that triggers the Run method
   */
  Object trigger;

  /**
   * set by run() on exit
   */
  protected Object returnValue = null;

  public RunResponse(Object onTrigger)
  {
    trigger = onTrigger;
  }

  public Object getTrigger() 
  {
   return trigger;
  }
  
  public void reset()
  {
    returnValue = null;
  }

  @Override
  public String toString()
  {
    return "Runner for " + trigger;
  }
  
  public Object getReturnValue() 
  {
	return returnValue;
  }
  
  public void setReturnValue(Object o) 
  {
	returnValue = o;
  }
}
